==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/xml/TestAnonTypeElement.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.xml.TestAnonTypeElement.X;
import org.apache.type_test.xml.TestAnonTypeElement.Y;


/**
 * <p>Java class for testAnonTypeElement element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testAnonTypeElement">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x">
 *             &lt;complexType>
 *               &lt;complexContent>
 *                 &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   &lt;sequence>
 *                     &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *                     &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                     &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                   &lt;/sequence>
 *                 &lt;/restriction>
 *               &lt;/complexContent>
 *             &lt;/complexType>
 *           &lt;/element>
 *           &lt;element name="y">
 *             &lt;complexType>
 *               &lt;complexContent>
 *                 &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   &lt;sequence>
 *                     &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *                     &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                     &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                   &lt;/sequence>
 *                 &lt;/restriction>
 *               &lt;/complexContent>
 *             &lt;/complexType>
 *           &lt;/element>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testAnonTypeElement")
public class TestAnonTypeElement {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected X x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected Y y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link X }
     *     
     */
    public X getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link X }
     *     
     */
    public void setX(X value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link Y }
     *     
     */
    public Y getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link Y }
     *     
     */
    public void setY(Y value) {
        this.y = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
     *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "varFloat",
        "varInt",
        "varString"
    })
    public static class X {

        @XmlElement(namespace = "http://apache.org/type_test/xml")
        protected float varFloat;
        @XmlElement(namespace = "http://apache.org/type_test/xml")
        protected int varInt;
        @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
        protected String varString;

        /**
         * Gets the value of the varFloat property.
         * 
         */
        public float getVarFloat() {
            return varFloat;
        }

        /**
         * Sets the value of the varFloat property.
         * 
         */
        public void setVarFloat(float value) {
            this.varFloat = value;
        }

        /**
         * Gets the value of the varInt property.
         * 
         */
        public int getVarInt() {
            return varInt;
        }

        /**
         * Sets the value of the varInt property.
         * 
         */
        public void setVarInt(int value) {
            this.varInt = value;
        }

        /**
         * Gets the value of the varString property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getVarString() {
            return varString;
        }

        /**
         * Sets the value of the varString property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setVarString(String value) {
            this.varString = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
     *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "varFloat",
        "varInt",
        "varString"
    })
    public static class Y {

        @XmlElement(namespace = "http://apache.org/type_test/xml")
        protected float varFloat;
        @XmlElement(namespace = "http://apache.org/type_test/xml")
        protected int varInt;
        @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
        protected String varString;

        /**
         * Gets the value of the varFloat property.
         * 
         */
        public float getVarFloat() {
            return varFloat;
        }

        /**
         * Sets the value of the varFloat property.
         * 
         */
        public void setVarFloat(float value) {
            this.varFloat = value;
        }

        /**
         * Gets the value of the varInt property.
         * 
         */
        public int getVarInt() {
            return varInt;
        }

        /**
         * Sets the value of the varInt property.
         * 
         */
        public void setVarInt(int value) {
            this.varInt = value;
        }

        /**
         * Gets the value of the varString property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getVarString() {
            return varString;
        }

        /**
         * Sets the value of the varString property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setVarString(String value) {
            this.varString = value;
        }

    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/xml/TestAnonTypeElement.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *                   &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                   &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="y">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *                   &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                   &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testAnonTypeElement")
public class TestAnonTypeElement {

    @XmlElement(required = true)
    protected TestAnonTypeElement.X x;
    @XmlElement(required = true)
    protected TestAnonTypeElement.Y y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link TestAnonTypeElement.X }
     *     
     */
    public TestAnonTypeElement.X getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link TestAnonTypeElement.X }
     *     
     */
    public void setX(TestAnonTypeElement.X value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link TestAnonTypeElement.Y }
     *     
     */
    public TestAnonTypeElement.Y getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link TestAnonTypeElement.Y }
     *     
     */
    public void setY(TestAnonTypeElement.Y value) {
        this.y = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
     *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "varFloat",
        "varInt",
        "varString"
    })
    public static class X {

        protected float varFloat;
        protected int varInt;
        @XmlElement(required = true)
        protected String varString;

        /**
         * Gets the value of the varFloat property.
         * 
         */
        public float getVarFloat() {
            return varFloat;
        }

        /**
         * Sets the value of the varFloat property.
         * 
         */
        public void setVarFloat(float value) {
            this.varFloat = value;
        }

        /**
         * Gets the value of the varInt property.
         * 
         */
        public int getVarInt() {
            return varInt;
        }

        /**
         * Sets the value of the varInt property.
         * 
         */
        public void setVarInt(int value) {
            this.varInt = value;
        }

        /**
         * Gets the value of the varString property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getVarString() {
            return varString;
        }

        /**
         * Sets the value of the varString property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setVarString(String value) {
            this.varString = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
     *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "varFloat",
        "varInt",
        "varString"
    })
    public static class Y {

        protected float varFloat;
        protected int varInt;
        @XmlElement(required = true)
        protected String varString;

        /**
         * Gets the value of the varFloat property.
         * 
         */
        public float getVarFloat() {
            return varFloat;
        }

        /**
         * Sets the value of the varFloat property.
         * 
         */
        public void setVarFloat(float value) {
            this.varFloat = value;
        }

        /**
         * Gets the value of the varInt property.
         * 
         */
        public int getVarInt() {
            return varInt;
        }

        /**
         * Sets the value of the varInt property.
         * 
         */
        public void setVarInt(int value) {
            this.varInt = value;
        }

        /**
         * Gets the value of the varString property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getVarString() {
            return varString;
        }

        /**
         * Sets the value of the varString property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setVarString(String value) {
            this.varString = value;
        }

    }

}
